@@ -97,6 +97,7 @@ namespace
 		virtual QMimeData* createMimeDataFromSelection() const;
 		virtual void insertFromMimeData(const QMimeData* source);
 		virtual void keyPressEvent(QKeyEvent* event);
+		virtual void inputMethodEvent(QInputMethodEvent* event);
 
 	private:
 		QByteArray mimeToRtf(const QMimeData* source) const;
@@ -162,6 +163,12 @@ namespace
 		}
 	}
 
+	void TextEdit::inputMethodEvent(QInputMethodEvent* event)
+	{
+		QTextEdit::inputMethodEvent(event);
+		Sound::play(Qt::Key_Any);
+	}
+
 	QByteArray TextEdit::mimeToRtf(const QMimeData* source) const
 	{
 		// Parse HTML
@@ -269,6 +276,8 @@ Document::Document(const QString& filename, int& current_wordcount, int& current
 
 	// Make it read-only until content is loaded
 	m_text->setReadOnly(true);
+
+	DocumentWatcher::instance()->addWatch(this);
 }
 
 //-----------------------------------------------------------------------------
@@ -318,7 +327,7 @@ bool Document::save()
 	}
 
 	// Write file to disk
-	DocumentWatcher::instance()->removeWatch(this);
+	DocumentWatcher::instance()->pauseWatch(this);
 	DocumentWriter writer;
 	writer.setFileName(m_filename);
 	writer.setType(m_filename.section(QLatin1Char('.'), -1));
@@ -333,7 +342,7 @@ bool Document::save()
 	} else {
 		cache();
 	}
-	DocumentWatcher::instance()->addWatch(this);
+	DocumentWatcher::instance()->resumeWatch(this);
 
 	if (!saved) {
 		QMessageBox::critical(window(), tr("Sorry"), tr("Unable to save '%1'.").arg(QDir::toNativeSeparators(m_filename)));
@@ -390,12 +399,13 @@ bool Document::rename()
 		QMessageBox::critical(window(), tr("Sorry"), tr("Unable to overwrite '%1'.").arg(QDir::toNativeSeparators(filename)));
 		return false;
 	}
-	DocumentWatcher::instance()->removeWatch(this);
+	DocumentWatcher::instance()->pauseWatch(this);
 	if (!QFile::rename(m_filename, filename)) {
-		DocumentWatcher::instance()->addWatch(this);
+		DocumentWatcher::instance()->resumeWatch(this);
 		QMessageBox::critical(window(), tr("Sorry"), tr("Unable to rename '%1'.").arg(QDir::toNativeSeparators(m_filename)));
 		return false;
 	}
+	DocumentWatcher::instance()->resumeWatch(this);
 	m_filename = filename;
 	save();
 	updateSaveLocation();
@@ -472,7 +482,6 @@ void Document::print()
 bool Document::loadFile(const QString& filename, int position)
 {
 	bool loaded = true;
-	DocumentWatcher::instance()->removeWatch(this);
 
 	if (filename.isEmpty()) {
 		m_text->setReadOnly(false);
@@ -563,7 +572,7 @@ bool Document::loadFile(const QString& filename, int position)
 	document->blockSignals(false);
 	m_text->blockSignals(false);
 
-	m_text->setReadOnly(!QFileInfo(m_filename).isWritable());
+	m_text->setReadOnly(!m_filename.isEmpty() ? !QFileInfo(m_filename).isWritable() : false);
 
 	// Restore cursor position
 	scrollBarRangeChanged(m_scrollbar->minimum(), m_scrollbar->maximum());
@@ -589,8 +598,8 @@ bool Document::loadFile(const QString& filename, int position)
 		focusText();
 	}
 
-	if (loaded) {
-		DocumentWatcher::instance()->addWatch(this);
+	if (loaded && !m_filename.isEmpty()) {
+		DocumentWatcher::instance()->updateWatch(this);
 	}
 	return loaded;
 }
@@ -1038,14 +1047,13 @@ void Document::updateWordCount(int position, int removed, int added)
 	if (m_old_states.contains(steps)) {
 		const QPair<QString, bool>& state = m_old_states[steps];
 		if (m_filename != state.first) {
-			DocumentWatcher::instance()->removeWatch(this);
 			m_filename = state.first;
 			if (m_filename.isEmpty()) {
 				findIndex();
 			} else {
-				DocumentWatcher::instance()->addWatch(this);
 				clearIndex();
 			}
+			DocumentWatcher::instance()->updateWatch(this);
 			emit changedName();
 		}
 		if (m_rich_text != state.second) {
